@@ -353,7 +353,7 @@ class EventManager:
                 if raiseEventNotListed:
                     raise EventNotListedException()
                 if not eventValueName == self.defaultIgnoreValue:
-                    self.logError("Eventvalue '%s' was not listed in the specified eventgroup" % (eventValueName))
+                    self.logWarning("Eventvalue '%s' was not listed in the specified eventgroup" % (eventValueName))
                 continue
 
             if eventName == self.defaultIgnoreValue:
