@@ -1,14 +1,21 @@
 from pyPhases import PluginAdapter
 
 from .Preprocessing import Preprocessing
-from .exporter.RecordNumpyMemmapExporter import RecordNumpyMemmapExporter
+
 
 class Plugin(PluginAdapter):
-    
     def __init__(self, project, options=...):
         super().__init__(project, options)
         self.project.systemExporter["RecordNumpyMemmapExporter"] = "pyPhasesPreprocessing"
-        
-    
+
+        def update(value):
+            if value is None or value == "preprocessing":
+                self.setupPreprocessing()
+
+        self.project.on("configChanged", update)
+
+    def setupPreprocessing(self):
+        Preprocessing.setup(self.project.config)
+
     def initPlugin(self):
-        Preprocessing.setup(self.project.config)
\ No newline at end of file
+        self.setupPreprocessing()
