@@ -696,13 +696,12 @@ class Preprocessing:
             events = self.preprocessEventsByConfig(events, self.extendEvents)
         return events
 
-    def preprocessEventsByConfig(self, events: List[Event], extendEventsConfig):
-        extendEventMap = extendEventsConfig
+    def preprocessEventsByConfig(self, events: List[Event], extendEventMap):
         for event in events:
             if event.name in extendEventMap:
                 addBefore, addAfter = extendEventMap[event.name]
                 event.start -= addBefore
-                event.duration += addAfter + addAfter
+                event.duration += addBefore + addAfter
         return events
 
     # def extractRecordAndAnnotations(self, recordName):
