@@ -145,7 +145,7 @@ class Preprocessing:
             # RIGHT, LEFT, BACK, FRONT (derived from the profusion xml, not sure if the mapping is actually correct)
             checkValues = set(uniquePositions) - set([0, 1, 2, 3])
             if len(checkValues) > 0:
-                raise Exception("domino position only supports 0, 1, 2, 3 as values ... fix here :-)")
+                raise Exception("shhs position only supports 0, 1, 2, 3 as values, conflicts: %s \n... fix here :-)"%checkValues)
 
             signal.signal += 10 # overwrite protection
             signal.signal[signal.signal == 10] = 5
